/*
** Module   : WrappedResource.java
** Abstract : interface for objects that can be checked for validity
**
** Copyright (c) 2005-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- --------------------------Description---------------------------
** 001 GES 20051125   @23506 Provides an interface for objects that can
**                           be checked for validity.
** 002 CA  20090227   @41381 Added isUnknown method - returns true if the
**                           wrapped resource is unknown.
** 003 OM  20130304          Refactored isValid and isUnknown of WrappedResource to valid 
**                           and unknown.
** 004 CA  20150502          The resource ID needs to be kept at the resource, so it can be 
**                           accessed after the resource is deleted.
*/

package com.goldencode.p2j.util;

/**
 * An API for objects that can be checked for validity.
 */
public interface WrappedResource
{
   /**
    * Reports if this object is valid for use.  
    *
    * @return   <code>true</code> if we are valid (can be used).
    */
   public boolean valid();
   
   /**
    * Reports if this object is unknown.  
    *
    * @return   <code>true</code> if object is unknown.
    */
   public boolean unknown();
   
   /**
    * Get this resource's ID, if is already set.
    * <p>
    * This is for internal usage only.  If you need the resource ID, use {@link handle#resourceId},
    * which will compute it and save it at the resource, too.
    * 
    * @return   The resource's ID or <code>null</code> if not set.
    */
   public Long id();
   
   /**
    * Set this resource's ID.
    * 
    * @param    id
    *           The resource's ID.
    */
   public void id(long id);
}
